@@ -25,7 +25,7 @@
 #include "videocollection.h"
 #include "../entrycomparison.h"
 
-#include <klocale.h>
+#include <KLocalizedString>
 
 namespace {
   static const char* video_general = I18N_NOOP("General");
@@ -242,7 +242,8 @@ int VideoCollection::sameEntry(Tellico::Data::EntryPtr entry1_, Tellico::Data::E
   res += EntryComparison::score(entry1_, entry2_, QLatin1String("director"), this);
   res += EntryComparison::score(entry1_, entry2_, QLatin1String("studio"), this);
   res += EntryComparison::score(entry1_, entry2_, QLatin1String("medium"), this);
+  // when imdb field is equal it is the same
+  res += 10*EntryComparison::score(entry1_, entry2_, QLatin1String("imdb"), this);
   return res;
 }
 
-#include "videocollection.moc"
