@@ -33,22 +33,22 @@
 #include "fieldformat.h"
 #include "tellico_strings.h"
 #include "images/imagefactory.h"
+#include "images/imagedirectory.h"
 #include "images/image.h"
 #include "images/imageinfo.h"
 #include "utils/stringset.h"
 #include "progressmanager.h"
 #include "core/tellico_config.h"
 #include "entrycomparison.h"
-#include "gui/guiproxy.h"
+#include "utils/guiproxy.h"
 #include "tellico_debug.h"
 
-#include <kmessagebox.h>
-#include <klocale.h>
-#include <kglobal.h>
-#include <kapplication.h>
+#include <KMessageBox>
+#include <KLocalizedString>
 
 #include <QRegExp>
 #include <QTimer>
+#include <QApplication>
 
 #include <unistd.h>
 
@@ -72,7 +72,7 @@ Tellico::Data::CollPtr Document::collection() const {
   return m_coll;
 }
 
-void Document::setURL(const KUrl& url_) {
+void Document::setURL(const QUrl& url_) {
   m_url = url_;
   if(m_url.fileName() != i18n(Tellico::untitledFilename)) {
     ImageFactory::setLocalDirectory(m_url);
@@ -106,8 +106,7 @@ bool Document::newDocument(int type_) {
   emit signalCollectionAdded(m_coll);
 
   slotSetModified(false);
-  KUrl url;
-  url.setFileName(i18n(Tellico::untitledFilename));
+  QUrl url = QUrl::fromLocalFile(i18n(Tellico::untitledFilename));
   setURL(url);
   m_validFile = false;
   m_fileFormat = Import::TellicoImporter::Unknown;
@@ -115,7 +114,7 @@ bool Document::newDocument(int type_) {
   return true;
 }
 
-bool Document::openDocument(const KUrl& url_) {
+bool Document::openDocument(const QUrl& url_) {
   MARK;
   m_loadAllImages = false;
   // delayed image loading only works for local files
@@ -175,7 +174,7 @@ bool Document::openDocument(const KUrl& url_) {
   return true;
 }
 
-bool Document::saveDocument(const KUrl& url_) {
+bool Document::saveDocument(const QUrl& url_, bool force_) {
   // FileHandler::queryExists calls FileHandler::writeBackupFile
   // so the only reason to check queryExists() is if the url to write to is different than the current one
   if(url_ == m_url) {
@@ -183,14 +182,14 @@ bool Document::saveDocument(const KUrl& url_) {
       return false;
     }
   } else {
-    if(!FileHandler::queryExists(url_)) {
+    if(!force_ && !FileHandler::queryExists(url_)) {
       return false;
     }
   }
 
   // in case we're still loading images, give that a chance to cancel
   m_cancelImageWriting = true;
-  kapp->processEvents();
+  qApp->processEvents();
 
   ProgressItem& item = ProgressManager::self()->newProgressItem(this, i18n("Saving file..."), false);
   ProgressItem::Done done(this);
@@ -205,11 +204,11 @@ bool Document::saveDocument(const KUrl& url_) {
   // case saving will over write the old file that has the images in it!
   if(includeImages) {
     totalSteps = 10;
-    item.setTotalSteps(10);
+    item.setTotalSteps(totalSteps);
     // since TellicoZipExporter uses 100 steps, then it will get 100/110 of the total progress
   } else {
     totalSteps = 100;
-    item.setTotalSteps(100);
+    item.setTotalSteps(totalSteps);
     m_cancelImageWriting = false;
     writeAllImages(imageLocation == Config::ImagesInAppDir ? ImageFactory::DataDir : ImageFactory::LocalDir, url_);
   }
@@ -237,7 +236,7 @@ bool Document::saveDocument(const KUrl& url_) {
     // if successful, doc is no longer modified
     slotSetModified(false);
   } else {
-    myDebug() << "not successful saving to " << url_;
+    myDebug() << "not successful saving to " << url_.url();
   }
   delete exporter;
   return success;
@@ -262,70 +261,103 @@ void Document::deleteContents() {
   if(m_coll) {
     m_coll->clear();
   }
-  m_coll = 0; // old collection gets deleted as a KSharedPtr
+  m_coll = 0; // old collection gets deleted as refcount goes to 0
   m_cancelImageWriting = true;
 }
 
 void Document::appendCollection(Tellico::Data::CollPtr coll_) {
-  if(!coll_) {
+  appendCollection(m_coll, coll_);
+}
+
+void Document::appendCollection(Tellico::Data::CollPtr coll1_, Tellico::Data::CollPtr coll2_) {
+  if(!coll1_ || !coll2_) {
     return;
   }
 
-  m_coll->blockSignals(true);
+  coll1_->blockSignals(true);
 
-  foreach(FieldPtr field, coll_->fields()) {
-    m_coll->mergeField(field);
+  foreach(FieldPtr field, coll2_->fields()) {
+    coll1_->mergeField(field);
   }
 
-  foreach(EntryPtr entry, coll_->entries()) {
+  Data::EntryList newEntries;
+  foreach(EntryPtr entry, coll2_->entries()) {
     Data::EntryPtr newEntry(new Data::Entry(*entry));
-    newEntry->setCollection(m_coll);
+    newEntry->setCollection(coll1_);
+    newEntries << newEntry;
   }
-  m_coll->addEntries(coll_->entries());
+  coll1_->addEntries(newEntries);
   // TODO: merge filters and loans
-  m_coll->blockSignals(false);
+  coll1_->blockSignals(false);
 }
 
 Tellico::Data::MergePair Document::mergeCollection(Tellico::Data::CollPtr coll_) {
+  return mergeCollection(m_coll, coll_);
+}
+
+Tellico::Data::MergePair Document::mergeCollection(Tellico::Data::CollPtr coll1_, Tellico::Data::CollPtr coll2_) {
   MergePair pair;
-  if(!coll_) {
+  if(!coll1_ || !coll2_) {
     return pair;
   }
 
-  m_coll->blockSignals(true);
-  Data::FieldList fields = coll_->fields();
+  coll1_->blockSignals(true);
+  Data::FieldList fields = coll2_->fields();
   foreach(FieldPtr field, fields) {
-    m_coll->mergeField(field);
+    coll1_->mergeField(field);
   }
 
-  EntryList currEntries = m_coll->entries();
-  EntryList newEntries = coll_->entries();
+  EntryList currEntries = coll1_->entries();
+  EntryList newEntries = coll2_->entries();
+  std::sort(currEntries.begin(), currEntries.end(), Data::EntryCmp(QLatin1String("title")));
+  std::sort(newEntries.begin(), newEntries.end(), Data::EntryCmp(QLatin1String("title")));
+
+  const int currTotal = currEntries.count();
+  int lastMatchId = 0;
+  bool checkSameId = false; // if the matching entries have the same id, then check that first for later comparisons
   foreach(EntryPtr newEntry, newEntries) {
     int bestMatch = 0;
-    Data::EntryPtr matchEntry;
-    foreach(EntryPtr currEntry, currEntries) {
-      int match = m_coll->sameEntry(currEntry, newEntry);
-      if(match >= EntryComparison::ENTRY_PERFECT_MATCH) {
+    Data::EntryPtr matchEntry, currEntry;
+    // first, if we're checking against same ID
+    if(checkSameId) {
+      currEntry = currEntries.first()->collection()->entryById(newEntry->id());
+      if(currEntry &&
+         currEntry->collection()->sameEntry(currEntry, newEntry) >= EntryComparison::ENTRY_PERFECT_MATCH) {
+        // only have to compare against perfect match
         matchEntry = currEntry;
-        break;
-      } else if(match >= EntryComparison::ENTRY_GOOD_MATCH && match > bestMatch) {
-        bestMatch = match;
-        matchEntry = currEntry;
-        // don't break, keep looking for better one
+      }
+    }
+    if(!matchEntry) {
+      // alternative is to loop over them all
+      for(int i = 0; i < currTotal; ++i) {
+        // since we're sorted by title, track the index of the previous match and starts comparison there
+        currEntry = currEntries.at((i+lastMatchId) % currTotal);
+        int match = currEntry->collection()->sameEntry(currEntry, newEntry);
+        if(match >= EntryComparison::ENTRY_PERFECT_MATCH) {
+          matchEntry = currEntry;
+          lastMatchId = (i+lastMatchId) % currTotal;
+          break;
+        } else if(match >= EntryComparison::ENTRY_GOOD_MATCH && match > bestMatch) {
+          bestMatch = match;
+          matchEntry = currEntry;
+          lastMatchId = (i+lastMatchId) % currTotal;
+          // don't break, keep looking for better one
+        }
       }
     }
     if(matchEntry) {
+      checkSameId = checkSameId || (matchEntry->id() == newEntry->id());
       mergeEntry(matchEntry, newEntry);
     } else {
       Data::EntryPtr e(new Data::Entry(*newEntry));
-      e->setCollection(m_coll);
+      e->setCollection(coll1_);
       // keep track of which entries got added
       pair.first.append(e);
     }
   }
-  m_coll->addEntries(pair.first);
+  coll1_->addEntries(pair.first);
   // TODO: merge filters and loans
-  m_coll->blockSignals(false);
+  coll1_->blockSignals(false);
   return pair;
 }
 
@@ -334,8 +366,7 @@ void Document::replaceCollection(Tellico::Data::CollPtr coll_) {
     return;
   }
 
-  KUrl url;
-  url.setFileName(i18n(Tellico::untitledFilename));
+  QUrl url = QUrl::fromLocalFile(i18n(Tellico::untitledFilename));
   setURL(url);
   m_validFile = false;
 
@@ -496,7 +527,7 @@ void Document::slotLoadAllImages() {
       }
       // this is the early loading, so just by calling imageById()
       // the image gets sucked from the zip file and written to disk
-      //by ImageFactory::imageById()
+      // by ImageFactory::imageById()
       if(ImageFactory::imageById(id).isNull()) {
         myDebug() << "entry title:" << entry->title();
       }
@@ -509,7 +540,7 @@ void Document::slotLoadAllImages() {
       break;
     }
     // stay responsive, do this in the background
-    kapp->processEvents();
+    qApp->processEvents();
   }
 
   if(m_cancelImageWriting) {
@@ -523,15 +554,18 @@ void Document::slotLoadAllImages() {
   m_importer = 0;
 }
 
-void Document::writeAllImages(int cacheDir_, const KUrl& localDir_) {
+// cacheDir_ is the location dir to write the images
+// localDir_ provide the new file location which is only needed if cacheDir == LocalDir
+void Document::writeAllImages(int cacheDir_, const QUrl& localDir_) {
   // images get 80 steps in saveDocument()
   const uint stepSize = 1 + qMax(1, m_coll->entryCount()/80); // add 1 since it could round off
   uint j = 1;
 
-  QString oldLocalDir = ImageFactory::localDir();
-  ImageFactory::setLocalDirectory(localDir_);
-
   ImageFactory::CacheDir cacheDir = static_cast<ImageFactory::CacheDir>(cacheDir_);
+  QScopedPointer<ImageDirectory> imgDir;
+  if(cacheDir == ImageFactory::LocalDir) {
+    imgDir.reset(new ImageDirectory(ImageFactory::localDirectory(localDir_)));
+  }
 
   QString id;
   StringSet images;
@@ -547,7 +581,14 @@ void Document::writeAllImages(int cacheDir_, const KUrl& localDir_) {
       if(ImageFactory::imageInfo(id).linkOnly) {
         continue;
       }
-      if(!ImageFactory::writeCachedImage(id, cacheDir)) {
+      // careful here, if we're writing to LocalDir, need to read from the old LocalDir and write to new
+      bool success;
+      if(cacheDir == ImageFactory::LocalDir) {
+        success = ImageFactory::writeCachedImage(id, imgDir.data());
+      } else {
+        success = ImageFactory::writeCachedImage(id, cacheDir);
+      }
+      if(!success) {
         myDebug() << "did not write image for entry title:" << entry->title();
       }
       if(m_cancelImageWriting) {
@@ -556,7 +597,7 @@ void Document::writeAllImages(int cacheDir_, const KUrl& localDir_) {
     }
     if(j%stepSize == 0) {
       ProgressManager::self()->setProgress(this, j/stepSize);
-      kapp->processEvents();
+      qApp->processEvents();
     }
     ++j;
     if(m_cancelImageWriting) {
@@ -569,7 +610,6 @@ void Document::writeAllImages(int cacheDir_, const KUrl& localDir_) {
   }
 
   m_cancelImageWriting = false;
-  ImageFactory::setLocalDirectory(oldLocalDir);
 }
 
 bool Document::pruneImages() {
@@ -797,5 +837,3 @@ QPair<Tellico::Data::FieldList, Tellico::Data::FieldList> Document::mergeFields(
   }
   return qMakePair(modified, created);
 }
-
-#include "document.moc"
