@@ -30,15 +30,15 @@
 #include "entry.h"
 #include "fieldformat.h"
 #include "tellico_kernel.h"
-#include "gui/cursorsaver.h"
+#include "utils/cursorsaver.h"
 #include "tellico_debug.h"
 
-#include <klocale.h>
-#include <kmessagebox.h>
-#include <kacceleratormanager.h>
-#include <kpushbutton.h>
-#include <kaction.h>
-#include <kvbox.h>
+#include <KLocalizedString>
+#include <KMessageBox>
+#include <KAcceleratorManager>
+#include <KSharedConfig>
+#include <KWindowConfig>
+#include <KHelpClient>
 
 #include <QStringList>
 #include <QObject>
@@ -46,66 +46,71 @@
 #include <QApplication>
 #include <QGridLayout>
 #include <QCloseEvent>
+#include <QVBoxLayout>
+#include <QPushButton>
+#include <QDialogButtonBox>
+#include <QTimer>
 
 namespace {
   // must be an even number
   static const int NCOLS = 2; // number of columns of GUI::FieldWidgets
+  static const char* dialogOptionsString = "Edit Dialog Options";
 }
 
 using Tellico::EntryEditDialog;
 
 EntryEditDialog::EntryEditDialog(QWidget* parent_)
-    : KDialog(parent_),
+    : QDialog(parent_),
       m_tabs(new GUI::TabWidget(this)),
       m_modified(false),
       m_isOrphan(false),
       m_isWorking(false),
       m_needReset(false) {
-  setCaption(i18n("Edit Entry"));
-  setButtons(Help|User1|Apply|Close);
-  setDefaultButton(User1);
-  setButtonGuiItem(User1, KGuiItem(i18n("&New Entry")));
+  setWindowTitle(i18n("Edit Entry"));
 
-  setMainWidget(m_tabs);
+  QVBoxLayout* mainLayout = new QVBoxLayout();
+  setLayout(mainLayout);
+  mainLayout->addWidget(m_tabs);
 
-  m_newBtn  = User1;
-  m_saveBtn = Apply;
+  QDialogButtonBox* buttonBox = new QDialogButtonBox(QDialogButtonBox::Help|
+                                                     QDialogButtonBox::Close|
+                                                     QDialogButtonBox::Apply);
+  connect(buttonBox, SIGNAL(helpRequested()), this, SLOT(slotHelp()));
+  mainLayout->addWidget(buttonBox);
+
+  m_newButton = new QPushButton();
+  buttonBox->addButton(m_newButton, QDialogButtonBox::ActionRole);
+  m_newButton->setDefault(true);
+  KGuiItem::assign(m_newButton, KGuiItem(i18n("&New Entry")));
+
+  m_saveButton = buttonBox->button(QDialogButtonBox::Apply);
+  m_saveButton->setEnabled(false);
   KGuiItem save = KStandardGuiItem::save();
   save.setText(i18n("Sa&ve Entry"));
-  setButtonGuiItem(m_saveBtn, save);
-  enableButton(m_saveBtn, false);
+  KGuiItem::assign(m_saveButton, save);
 
-  // close is handled by slotButtonClicked()
-//  connect(this, SIGNAL(closeClicked()), SLOT(slotClose()));
-  connect(this, SIGNAL(applyClicked()), SLOT(slotHandleSave()));
-  connect(this, SIGNAL(user1Clicked()), SLOT(slotHandleNew()));
-
-  setHelp(QLatin1String("entry-editor"));
-
-  KConfigGroup config(KGlobal::config(), QLatin1String("Edit Dialog Options"));
-  restoreDialogSize(config);
+  connect(buttonBox->button(QDialogButtonBox::Close), SIGNAL(clicked()), SLOT(slotClose()));
+  connect(m_saveButton, SIGNAL(clicked()), SLOT(slotHandleSave()));
+  connect(m_newButton, SIGNAL(clicked()), SLOT(slotHandleNew()));
 }
 
-// we want to try the close button
-void EntryEditDialog::slotButtonClicked(int button_) {
-  if(button_ == KDialog::Close) {
-    slotClose();
-  } else {
-    KDialog::slotButtonClicked(button_);
-  }
+void EntryEditDialog::reject() {
+  slotClose();
+}
+
+void EntryEditDialog::slotHelp() {
+  KHelpClient::invokeHelp(QLatin1String("entry-editor"));
 }
 
 void EntryEditDialog::slotClose() {
   // check to see if an entry should be saved before hiding
   // block signals so the entry view and selection isn't cleared
   if(queryModified()) {
-    hide();
+    accept();
     // make sure to reset values in the dialog
     m_needReset = true;
     setContents(m_currEntries);
     slotSetModified(false);
-    KConfigGroup config(KGlobal::config(), QLatin1String("Edit Dialog Options"));
-    saveDialogSize(config);
   }
 }
 
@@ -113,11 +118,10 @@ void EntryEditDialog::slotReset() {
   if(m_isWorking) {
     return;
   }
-//  myDebug();
 
   slotSetModified(false);
-  enableButton(m_saveBtn, false);
-  setButtonText(m_saveBtn, i18n("Sa&ve Entry"));
+  m_saveButton->setEnabled(false);
+  m_saveButton->setText(i18n("Sa&ve Entry"));
   m_currColl = 0;
   m_currEntries.clear();
 
@@ -129,13 +133,12 @@ void EntryEditDialog::slotReset() {
   m_widgetDict.clear();
 }
 
-void EntryEditDialog::setLayout(Tellico::Data::CollPtr coll_) {
+void EntryEditDialog::resetLayout(Tellico::Data::CollPtr coll_) {
   if(!coll_ || m_isWorking) {
     return;
   }
-//  myDebug();
 
-  button(m_newBtn)->setIcon(KIcon(Kernel::self()->collectionTypeName()));
+  m_newButton->setIcon(QIcon::fromTheme(Kernel::self()->collectionTypeName()));
 
   setUpdatesEnabled(false);
   if(m_tabs->count() > 0) {
@@ -171,12 +174,10 @@ void EntryEditDialog::setLayout(Tellico::Data::CollPtr coll_) {
 
     // if this layout model is changed, be sure to check slotUpdateField()
     QWidget* page = new QWidget(m_tabs);
-    // (parent, margin, spacing)
     QBoxLayout* boxLayout = new QVBoxLayout(page);
 
     QWidget* grid = new QWidget(page);
     gridList.append(grid);
-    // (parent, nrows, ncols, margin, spacing)
     // spacing gets a bit weird, if there are absolutely no Choice fields,
     // then spacing should be 5, which is set later
     QGridLayout* layout = new QGridLayout(grid);
@@ -269,7 +270,7 @@ void EntryEditDialog::setLayout(Tellico::Data::CollPtr coll_) {
 // this doesn't seem to work
 //  setSizePolicy(QSizePolicy::MinimumExpanding, QSizePolicy::Minimum);
 // so do this instead
-  layout()->invalidate(); // needed so the sizeHint() gets recalculated
+//  layout()->invalidate(); // needed so the sizeHint() gets recalculated
   m_tabs->setMinimumHeight(m_tabs->minimumSizeHint().height());
   m_tabs->setMinimumWidth(m_tabs->sizeHint().width());
 
@@ -283,7 +284,6 @@ void EntryEditDialog::slotHandleNew() {
   if(!m_currColl || !queryModified()) {
     return;
   }
-//  myDebug();
 
   m_tabs->setCurrentIndex(0);
   m_tabs->setFocusToFirstChild();
@@ -386,7 +386,7 @@ void EntryEditDialog::slotHandleSave() {
       Kernel::self()->modifyEntries(oldEntries, m_currEntries, fieldNames);
     }
     if(!m_currEntries.isEmpty() && !m_currEntries[0]->title().isEmpty()) {
-      setCaption(i18n("Edit Entry") + QLatin1String(" - ") + m_currEntries[0]->title());
+      setWindowTitle(i18n("Edit Entry") + QLatin1String(" - ") + m_currEntries[0]->title());
     }
   }
 
@@ -399,7 +399,6 @@ void EntryEditDialog::clear() {
   if(m_isWorking) {
     return;
   }
-//  myDebug();
 
   m_isWorking = true;
   // clear the widgets
@@ -410,7 +409,7 @@ void EntryEditDialog::clear() {
   }
   m_modifiedFields.clear();
 
-  setCaption(i18n("Edit Entry"));
+  setWindowTitle(i18n("Edit Entry"));
 
   if(m_isOrphan) {
     if(m_currEntries.count() > 1) {
@@ -420,7 +419,7 @@ void EntryEditDialog::clear() {
   }
   m_currEntries.clear();
 
-  setButtonText(m_saveBtn, i18n("Sa&ve Entry"));
+  m_saveButton->setText(i18n("Sa&ve Entry"));
 
   m_isWorking = false;
   slotSetModified(false);
@@ -456,7 +455,7 @@ void EntryEditDialog::setContents(Tellico::Data::EntryList entries_) {
   }
 
   // multiple entries, so don't set caption
-  setCaption(i18n("Edit Entries"));
+  setWindowTitle(i18n("Edit Entries"));
 
   m_currEntries = entries_;
   m_isWorking = true;
@@ -482,14 +481,13 @@ void EntryEditDialog::setContents(Tellico::Data::EntryList entries_) {
   blockSignals(false);
   m_isWorking = false;
 
-  setButtonText(m_saveBtn, i18n("Sa&ve Entries"));
+  m_saveButton->setText(i18n("Sa&ve Entries"));
 }
 
 void EntryEditDialog::setContents(Tellico::Data::EntryPtr entry_) {
   if(m_isWorking || !queryModified()) {
     return;
   }
-//  myDebug();
 
   if(!entry_) {
     myDebug() << "null entry pointer";
@@ -506,7 +504,7 @@ void EntryEditDialog::setContents(Tellico::Data::EntryPtr entry_) {
   m_currEntries.append(entry_);
 
   if(!entry_->title().isEmpty()) {
-    setCaption(i18n("Edit Entry") + QLatin1String(" - ") + entry_->title());
+    setWindowTitle(i18n("Edit Entry") + QLatin1String(" - ") + entry_->title());
   }
 
   if(m_currColl != entry_->collection()) {
@@ -527,7 +525,7 @@ void EntryEditDialog::setContents(Tellico::Data::EntryPtr entry_) {
   } // end field loop
 
   if(entry_->isOwned()) {
-    setButtonText(m_saveBtn, i18n("Sa&ve Entry"));
+    m_saveButton->setText(i18n("Sa&ve Entry"));
     slotSetModified(false);
   } else {
     // saving is necessary for unowned entries
@@ -556,7 +554,7 @@ void EntryEditDialog::removeField(Tellico::Data::CollPtr, Tellico::Data::FieldPt
       m_tabs->removeTab(m_tabs->indexOf(w));
       delete w; // automatically deletes child widget
     } else {
-      // much of this replicates code in setLayout()
+      // much of this replicates code in resetLayout()
       QGridLayout* layout = static_cast<QGridLayout*>(widget->parentWidget()->layout());
       delete widget; // automatically removes from layout
 
@@ -632,11 +630,10 @@ void EntryEditDialog::updateCompletions(Tellico::Data::EntryPtr entry_) {
 
 void EntryEditDialog::slotSetModified(bool mod_/*=true*/) {
   m_modified = mod_;
-  enableButton(m_saveBtn, mod_);
+  m_saveButton->setEnabled(mod_);
 }
 
 bool EntryEditDialog::queryModified() {
-//  myDebug() << "modified is" << m_modified;
   bool ok = true;
   // assume that if the dialog is hidden, we shouldn't ask the user to modify changes
   if(!isVisible()) {
@@ -671,7 +668,7 @@ bool EntryEditDialog::queryModified() {
 void EntryEditDialog::addField(Tellico::Data::CollPtr coll_, Tellico::Data::FieldPtr field_) {
   Q_ASSERT(coll_ == m_currColl);
   Q_UNUSED(field_);
-  setLayout(coll_);
+  resetLayout(coll_);
 }
 
 // modified fields will always have the same name
@@ -688,7 +685,7 @@ void EntryEditDialog::modifyField(Tellico::Data::CollPtr coll_, Tellico::Data::F
   if(oldField_->type() != newField_->type()
      || (oldField_->category() != newField_->category() && !newField_->isSingleCategory())) {
     bool modified = m_modified;
-    setLayout(coll_);
+    resetLayout(coll_);
     setContents(m_currEntries);
     m_modified = modified;
     return;
@@ -745,17 +742,43 @@ void EntryEditDialog::fieldValueChanged(Data::FieldPtr field_) {
   if(!m_modifiedFields.contains(field_)) {
     m_modifiedFields.append(field_);
   }
-  slotSetModified();
+  slotSetModified(true);
+}
+
+void EntryEditDialog::showEvent(QShowEvent* event_) {
+  QDialog::showEvent(event_);
+/*
+  I attempted to read and restore window size here, but it didn't work (July 2016)
+  I discovered that I had to put it in a timer. Somewhere, the resize event or something
+  was overriding any size changes I did here. Calling this->resize() would work but 
+  windowHandle()->resize() would not (as KWindowConfig::restoreWindowSize uses)
+*/
+  QTimer::singleShot(0, this, SLOT(slotUpdateSize()));
+}
+
+void EntryEditDialog::slotUpdateSize() {
+  KConfigGroup config(KSharedConfig::openConfig(), QLatin1String(dialogOptionsString));
+  KWindowConfig::restoreWindowSize(windowHandle(), config);
+}
+
+void EntryEditDialog::hideEvent(QHideEvent* event_) {
+  KConfigGroup config(KSharedConfig::openConfig(), QLatin1String(dialogOptionsString));
+  KWindowConfig::saveWindowSize(windowHandle(), config);
+  config.sync();
+
+  if(queryModified()) {
+    QDialog::hideEvent(event_);
+  } else {
+    event_->ignore();
+  }
 }
 
 void EntryEditDialog::closeEvent(QCloseEvent* event_) {
   // check to see if an entry should be saved before hiding
   // block signals so the entry view and selection isn't cleared
   if(queryModified()) {
-    KDialog::closeEvent(event_);
+    QDialog::closeEvent(event_);
   } else {
     event_->ignore();
   }
 }
-
-#include "entryeditdialog.moc"
