@@ -34,11 +34,10 @@
 #include "entrymatchdialog.h"
 #include "tellico_debug.h"
 
-#include <klocale.h>
-#include <kiconloader.h>
-#include <kapplication.h>
+#include <KLocalizedString>
 
 #include <QTimer>
+#include <QApplication>
 
 namespace {
   static const int CHECK_COLLECTION_IMAGES_STEP_SIZE = 10;
@@ -144,7 +143,7 @@ void EntryUpdater::slotDone() {
       return;
     }
   }
-  kapp->processEvents();
+  qApp->processEvents();
   // so the entry updater can clean up a bit
   QTimer::singleShot(500, this, SLOT(slotStartNext()));
 }
@@ -164,7 +163,7 @@ void EntryUpdater::slotResult(Tellico::Fetch::FetchResult* result_) {
       result_->fetcher->stop();
     }
   }
-  kapp->processEvents();
+  qApp->processEvents();
 }
 
 void EntryUpdater::slotCancel() {
@@ -265,4 +264,3 @@ void EntryUpdater::slotCleanup() {
   deleteLater();
 }
 
-#include "entryupdater.moc"
