@@ -31,7 +31,8 @@
 
 #include <QPointer>
 
-class KIntSpinBox;
+class QSpinBox;
+
 class KJob;
 namespace KIO {
   class StoredTransferJob;
@@ -70,11 +71,11 @@ public:
     virtual void saveConfigHook(KConfigGroup&);
     virtual QString preferredName() const = 0;
   private:
-    KIntSpinBox* m_numCast;
+    QSpinBox* m_numCast;
   };
   friend class ConfigWidget;
 
-private slots:
+private Q_SLOTS:
   void slotComplete(KJob* job);
 
 private:
@@ -84,6 +85,7 @@ private:
 
   virtual void search();
   virtual FetchRequest updateRequest(Data::EntryPtr entry);
+  Data::CollPtr createCollection() const;
   void populateEntry(Data::EntryPtr entry, const QVariantMap& resultMap);
 
   QHash<int, Data::EntryPtr> m_entries;
