@@ -23,8 +23,8 @@
  ***************************************************************************/
 
 #include "animenfofetcher.h"
-#include "../gui/guiproxy.h"
-#include "../tellico_utils.h"
+#include "../utils/guiproxy.h"
+#include "../utils/string_utils.h"
 #include "../collections/bookcollection.h"
 #include "../collections/videocollection.h"
 #include "../entry.h"
@@ -33,16 +33,18 @@
 #include "../images/imagefactory.h"
 #include "../tellico_debug.h"
 
-#include <klocale.h>
-#include <kconfig.h>
-#include <kio/job.h>
-#include <kio/jobuidelegate.h>
+#include <KLocalizedString>
+#include <KConfig>
+#include <KIO/Job>
+#include <KIO/JobUiDelegate>
+#include <KJobWidgets/KJobWidgets>
 
 #include <QRegExp>
 #include <QLabel>
 #include <QFile>
 #include <QTextStream>
 #include <QVBoxLayout>
+#include <QUrlQuery>
 
 namespace {
   static const char* ANIMENFO_BASE_URL = "http://www.animenfo.com/search.php";
@@ -76,17 +78,18 @@ void AnimeNfoFetcher::search() {
   m_started = true;
   m_matches.clear();
 
-  KUrl u(ANIMENFO_BASE_URL);
-  u.addQueryItem(QLatin1String("action"),   QLatin1String("Go"));
-  u.addQueryItem(QLatin1String("option"),   QLatin1String("keywords"));
+  QUrl u(QString::fromLatin1(ANIMENFO_BASE_URL));
+  QUrlQuery q;
+  q.addQueryItem(QLatin1String("action"),   QLatin1String("Go"));
+  q.addQueryItem(QLatin1String("option"),   QLatin1String("keywords"));
 
   switch(request().collectionType) {
     case Data::Collection::Book:
-      u.addQueryItem(QLatin1String("queryin"),  QLatin1String("manga_titles"));
+      q.addQueryItem(QLatin1String("queryin"),  QLatin1String("manga_titles"));
       break;
 
     case Data::Collection::Video:
-      u.addQueryItem(QLatin1String("queryin"),  QLatin1String("anime_titles"));
+      q.addQueryItem(QLatin1String("queryin"),  QLatin1String("anime_titles"));
       break;
 
     default:
@@ -97,7 +100,7 @@ void AnimeNfoFetcher::search() {
 
   switch(request().key) {
     case Keyword:
-      u.addQueryItem(QLatin1String("query"), request().value);
+      q.addQueryItem(QLatin1String("query"), request().value);
       break;
 
     default:
@@ -105,10 +108,11 @@ void AnimeNfoFetcher::search() {
       stop();
       return;
   }
-//  myDebug() << "url:" << u.url();
+  u.setQuery(q);
+//  myDebug() << "url:" << u;
 
   m_job = KIO::storedGet(u, KIO::NoReload, KIO::HideProgressInfo);
-  m_job->ui()->setWindow(GUI::Proxy::widget());
+  KJobWidgets::setWindow(m_job, GUI::Proxy::widget());
   connect(m_job, SIGNAL(result(KJob*)),
           SLOT(slotComplete(KJob*)));
 }
@@ -146,6 +150,16 @@ void AnimeNfoFetcher::slotComplete(KJob*) {
   m_job = 0;
 
   QString s = Tellico::decodeHTML(data);
+#if 0
+  myWarning() << "Remove debug from animenfofetcher.cpp";
+  QFile f(QLatin1String("/tmp/test.html"));
+  if(f.open(QIODevice::WriteOnly)) {
+    QTextStream t(&f);
+    t.setCodec("UTF-8");
+    t << s;
+  }
+  f.close();
+#endif
 
   QRegExp infoRx(QLatin1String("<td\\s+[^>]*class\\s*=\\s*[\"']anime_info[\"'][^>]*>(.*)</td>"), Qt::CaseInsensitive);
   infoRx.setMinimal(true);
@@ -160,7 +174,7 @@ void AnimeNfoFetcher::slotComplete(KJob*) {
   for(int pos = infoRx.indexIn(s); m_started && pos > -1; pos = infoRx.indexIn(s, pos+1)) {
     if(n == 0 && !u.isEmpty()) {
       FetchResult* r = new FetchResult(Fetcher::Ptr(this), t, y);
-      KUrl url(KUrl(ANIMENFO_BASE_URL), u);
+      QUrl url = QUrl(QString::fromLatin1(ANIMENFO_BASE_URL)).resolved(QUrl(u));
       url.setQuery(QString());
       m_matches.insert(r->uid, url);
       // don't emit signal until after putting url in matches hash
@@ -195,7 +209,7 @@ void AnimeNfoFetcher::slotComplete(KJob*) {
   // grab last response
   if(!u.isEmpty()) {
     FetchResult* r = new FetchResult(Fetcher::Ptr(this), t, y, QString());
-    KUrl url(KUrl(ANIMENFO_BASE_URL), u);
+    QUrl url = QUrl(QString::fromLatin1(ANIMENFO_BASE_URL)).resolved(QUrl(u));
     url.setQuery(QString());
     m_matches.insert(r->uid, url);
     // don't emit signal until after putting url in matches hash
@@ -212,7 +226,7 @@ Tellico::Data::EntryPtr AnimeNfoFetcher::fetchEntryHook(uint uid_) {
     return entry;
   }
 
-  KUrl url = m_matches[uid_];
+  QUrl url = m_matches[uid_];
   if(url.isEmpty()) {
     myWarning() << "no url in map";
     return Data::EntryPtr();
@@ -244,7 +258,7 @@ Tellico::Data::EntryPtr AnimeNfoFetcher::fetchEntryHook(uint uid_) {
   return entry;
 }
 
-Tellico::Data::EntryPtr AnimeNfoFetcher::parseEntry(const QString& str_, const KUrl& url_) {
+Tellico::Data::EntryPtr AnimeNfoFetcher::parseEntry(const QString& str_, const QUrl& url_) {
  // myDebug();
  // class might be anime_info_top
   QRegExp infoRx(QLatin1String("<td\\s+[^>]*class\\s*=\\s*[\"']anime_info[^>]*>(.*)</td>"), Qt::CaseInsensitive);
@@ -402,7 +416,7 @@ Tellico::Data::EntryPtr AnimeNfoFetcher::parseEntry(const QString& str_, const K
   imgRx.setMinimal(true);
   int pos = imgRx.indexIn(s);
   if(pos > -1) {
-    KUrl imgURL(KUrl(ANIMENFO_BASE_URL), imgRx.cap(1));
+    QUrl imgURL = QUrl(QLatin1String(ANIMENFO_BASE_URL)).resolved(QUrl(imgRx.cap(1)));
     QString id = ImageFactory::addImage(imgURL, true);
     if(!id.isEmpty()) {
       entry->setField(QLatin1String("cover"), id);
@@ -498,5 +512,3 @@ AnimeNfoFetcher::ConfigWidget::ConfigWidget(QWidget* parent_, const AnimeNfoFetc
 QString AnimeNfoFetcher::ConfigWidget::preferredName() const {
   return AnimeNfoFetcher::defaultName();
 }
-
-#include "animenfofetcher.moc"
