@@ -23,6 +23,7 @@
  ***************************************************************************/
 
 #include <config.h>
+
 #include "fetcherinitializer.h"
 #include "amazonfetcher.h"
 #include "imdbfetcher.h"
@@ -33,13 +34,11 @@
 #include "entrezfetcher.h"
 #include "execexternalfetcher.h"
 #include "animenfofetcher.h"
-#include "yahoofetcher.h"
 #include "ibsfetcher.h"
 #include "isbndbfetcher.h"
 #include "gcstarpluginfetcher.h"
 #include "crossreffetcher.h"
 #include "arxivfetcher.h"
-#include "citebasefetcher.h"
 #include "bibsonomyfetcher.h"
 #include "googlescholarfetcher.h"
 #include "discogsfetcher.h"
@@ -51,7 +50,6 @@
 #include "multifetcher.h"
 #include "freebasefetcher.h"
 #include "filmasterfetcher.h"
-#include "masfetcher.h"
 #include "hathitrustfetcher.h"
 #include "vndbfetcher.h"
 #include "dvdfrfetcher.h"
@@ -61,12 +59,14 @@
 #include "googlebookfetcher.h"
 #include "springerfetcher.h"
 #include "allocinefetcher.h"
-#include "screenrushfetcher.h"
-#include "filmstartsfetcher.h"
-#include "sensacinefetcher.h"
-#include "beyazperdefetcher.h"
 #include "thegamesdbfetcher.h"
 #include "dblpfetcher.h"
+#include "mrlookupfetcher.h"
+#include "boardgamegeekfetcher.h"
+#include "bedethequefetcher.h"
+#include "omdbfetcher.h"
+#include "kinopoiskfetcher.h"
+#include "videogamegeekfetcher.h"
 
 /**
  * Ideally, I'd like these initializations to be in each cpp file for each collection type
@@ -86,41 +86,39 @@ Tellico::Fetch::FetcherInitializer::FetcherInitializer() {
   RegisterFetcher<Fetch::EntrezFetcher> registerEntrez(Entrez);
   RegisterFetcher<Fetch::ExecExternalFetcher> registerExternal(ExecExternal);
   RegisterFetcher<Fetch::AnimeNfoFetcher> registerAnimeNfo(AnimeNfo);
-//  RegisterFetcher<Fetch::YahooFetcher> registerYahoo(Yahoo);
   RegisterFetcher<Fetch::IBSFetcher> registerIBS(IBS);
   RegisterFetcher<Fetch::ISBNdbFetcher> registerISBNdb(ISBNdb);
   RegisterFetcher<Fetch::GCstarPluginFetcher> registerGCstar(GCstarPlugin);
   RegisterFetcher<Fetch::CrossRefFetcher> registerCrossRef(CrossRef);
   RegisterFetcher<Fetch::ArxivFetcher> registerArxiv(Arxiv);
-  RegisterFetcher<Fetch::CitebaseFetcher> registerCitebase(Citebase);
   RegisterFetcher<Fetch::BibsonomyFetcher> registerBibsonomy(Bibsonomy);
   RegisterFetcher<Fetch::GoogleScholarFetcher> registerGoogle(GoogleScholar);
-  RegisterFetcher<Fetch::DiscogsFetcher> registerDiscogs(Discogs);
   RegisterFetcher<Fetch::WineComFetcher> registerWine(WineCom);
   RegisterFetcher<Fetch::MusicBrainzFetcher> registerMB(MusicBrainz);
   RegisterFetcher<Fetch::GiantBombFetcher> registerBomb(GiantBomb);
   RegisterFetcher<Fetch::OpenLibraryFetcher> registerOpenLibrary(OpenLibrary);
   RegisterFetcher<Fetch::MultiFetcher> registerMulti(Multiple);
-#ifdef HAVE_QJSON
+  RegisterFetcher<Fetch::DiscogsFetcher> registerDiscogs(Discogs);
   RegisterFetcher<Fetch::TheMovieDBFetcher> registerTMDB(TheMovieDB);
   RegisterFetcher<Fetch::FreebaseFetcher> registerFreebase(Freebase);
   RegisterFetcher<Fetch::FilmasterFetcher> registerFilmaster(Filmaster);
   RegisterFetcher<Fetch::GoogleBookFetcher> registerGoogleBook(GoogleBook);
-  RegisterFetcher<Fetch::MASFetcher> registerMAS(MAS);
   RegisterFetcher<Fetch::HathiTrustFetcher> registerHathiTrust(HathiTrust);
   RegisterFetcher<Fetch::VNDBFetcher> registerVNDB(VNDB);
   RegisterFetcher<Fetch::AllocineFetcher> registerAllocine(Allocine);
-  // add these back if the API gets updated
-//  RegisterFetcher<Fetch::ScreenRushFetcher> registerScreenRush(ScreenRush);
-//  RegisterFetcher<Fetch::FilmStartsFetcher> registerFilmStarts(FilmStarts);
-//  RegisterFetcher<Fetch::SensaCineFetcher> registerSensaCine(SensaCine);
-//  RegisterFetcher<Fetch::BeyazperdeFetcher> registerBeyazperde(Beyazperde);
-#endif
+  RegisterFetcher<Fetch::MovieMeterFetcher> registerMovieMeter(MovieMeter);
   RegisterFetcher<Fetch::DVDFrFetcher> registerDVDFr(DVDFr);
   RegisterFetcher<Fetch::DoubanFetcher> registerDouban(Douban);
   RegisterFetcher<Fetch::BiblioShareFetcher> registerBiblioShare(BiblioShare);
-  RegisterFetcher<Fetch::MovieMeterFetcher> registerMovieMeter(MovieMeter);
   RegisterFetcher<Fetch::SpringerFetcher> registerSpringer(Springer);
   RegisterFetcher<Fetch::TheGamesDBFetcher> registerTheGamesDB(TheGamesDB);
   RegisterFetcher<Fetch::DBLPFetcher> registerDBLP(DBLP);
+  RegisterFetcher<Fetch::MRLookupFetcher> registerMRLookup(MRLookup);
+  RegisterFetcher<Fetch::BoardGameGeekFetcher> registerBGG(BoardGameGeek);
+  RegisterFetcher<Fetch::BedethequeFetcher> registerBD(Bedetheque);
+  RegisterFetcher<Fetch::OMDBFetcher> registerOMDB(OMDB);
+  RegisterFetcher<Fetch::KinoPoiskFetcher> registerKinoPoisk(KinoPoisk);
+  RegisterFetcher<Fetch::VideoGameGeekFetcher> registerVGG(VideoGameGeek);
+
+  Fetch::Manager::self()->loadFetchers();
 }
