@@ -30,7 +30,8 @@
 
 #include <QPointer>
 
-class KLineEdit;
+class QLineEdit;
+
 class KJob;
 namespace KIO {
   class StoredTransferJob;
@@ -69,7 +70,7 @@ public:
     virtual void saveConfigHook(KConfigGroup&);
     virtual QString preferredName() const;
   private:
-    KLineEdit* m_apiKeyEdit;
+    QLineEdit* m_apiKeyEdit;
   };
   friend class ConfigWidget;
 
@@ -77,7 +78,7 @@ public:
   static QString defaultIcon();
   static StringHash allOptionalFields();
 
-private slots:
+private Q_SLOTS:
   void slotComplete(KJob* job);
 
 private:
