@@ -22,35 +22,36 @@
  *                                                                         *
  ***************************************************************************/
 
-#include <config.h>
 #include "themoviedbfetcher.h"
 #include "../collections/videocollection.h"
+#include "../images/imagefactory.h"
 #include "../gui/combobox.h"
-#include "../gui/guiproxy.h"
 #include "../core/filehandler.h"
-#include "../tellico_utils.h"
+#include "../utils/guiproxy.h"
+#include "../utils/string_utils.h"
 #include "../tellico_debug.h"
 
-#include <klocale.h>
-#include <kio/job.h>
-#include <kio/jobuidelegate.h>
+#include <KLocalizedString>
 #include <KConfigGroup>
+#include <KJob>
+#include <KJobUiDelegate>
+#include <KJobWidgets/KJobWidgets>
+#include <KIO/StoredTransferJob>
 
+#include <QUrl>
 #include <QLabel>
 #include <QFile>
 #include <QTextStream>
 #include <QGridLayout>
 #include <QTextCodec>
-
-#ifdef HAVE_QJSON
-#include <qjson/serializer.h>
-#include <qjson/parser.h>
-#endif
+#include <QJsonDocument>
+#include <QJsonObject>
+#include <QUrlQuery>
 
 namespace {
   static const int THEMOVIEDB_MAX_RETURNS_TOTAL = 20;
-  static const char* THEMOVIEDB_API_URL = "http://api.themoviedb.org";
-  static const char* THEMOVIEDB_API_VERSION = "3";
+  static const char* THEMOVIEDB_API_URL = "https://api.themoviedb.org";
+  static const char* THEMOVIEDB_API_VERSION = "3"; // krazy:exclude=doublequote_chars
   static const char* THEMOVIEDB_API_KEY = "919890b4128d33c729dc368209ece555";
 }
 
@@ -78,11 +79,7 @@ QString TheMovieDBFetcher::attribution() const {
 }
 
 bool TheMovieDBFetcher::canSearch(FetchKey k) const {
-#ifdef HAVE_QJSON
   return k == Title;
-#else
-  return false;
-#endif
 }
 
 bool TheMovieDBFetcher::canFetch(int type) const {
@@ -121,7 +118,6 @@ void TheMovieDBFetcher::search() {
 }
 
 void TheMovieDBFetcher::continueSearch() {
-#ifdef HAVE_QJSON
   m_started = true;
 
   if(m_apiKey.isEmpty()) {
@@ -130,15 +126,20 @@ void TheMovieDBFetcher::continueSearch() {
     return;
   }
 
-  KUrl u(THEMOVIEDB_API_URL);
-  u.setPath(QLatin1String(THEMOVIEDB_API_VERSION));
+  QUrl u(QString::fromLatin1(THEMOVIEDB_API_URL));
+  u.setPath(QLatin1Char('/') + QLatin1String(THEMOVIEDB_API_VERSION));
 
   switch(request().key) {
     case Title:
-      u.addPath(QLatin1String("/search/movie"));
-      u.addQueryItem(QLatin1String("api_key"), m_apiKey);
-      u.addQueryItem(QLatin1String("language"), m_locale);
-      u.addQueryItem(QLatin1String("query"), request().value);
+      u = u.adjusted(QUrl::StripTrailingSlash);
+      u.setPath(u.path() + QLatin1String("/search/movie"));
+      {
+        QUrlQuery q;
+        q.addQueryItem(QLatin1String("api_key"), m_apiKey);
+        q.addQueryItem(QLatin1String("language"), m_locale);
+        q.addQueryItem(QLatin1String("query"), request().value);
+        u.setQuery(q);
+      }
       break;
 
     default:
@@ -148,11 +149,8 @@ void TheMovieDBFetcher::continueSearch() {
   }
 
   m_job = KIO::storedGet(u, KIO::NoReload, KIO::HideProgressInfo);
-  m_job->ui()->setWindow(GUI::Proxy::widget());
+  KJobWidgets::setWindow(m_job, GUI::Proxy::widget());
   connect(m_job, SIGNAL(result(KJob*)), SLOT(slotComplete(KJob*)));
-#else
-  stop();
-#endif
 }
 
 void TheMovieDBFetcher::stop() {
@@ -174,17 +172,18 @@ Tellico::Data::EntryPtr TheMovieDBFetcher::fetchEntryHook(uint uid_) {
     return Data::EntryPtr();
   }
 
-#ifdef HAVE_QJSON
   QString id = entry->field(QLatin1String("tmdb-id"));
   if(!id.isEmpty()) {
     // quiet
-    KUrl u(THEMOVIEDB_API_URL);
-    u.setPath(QString::fromLatin1("%1/movie/%2")
+    QUrl u(QString::fromLatin1(THEMOVIEDB_API_URL));
+    u.setPath(QString::fromLatin1("/%1/movie/%2")
               .arg(QLatin1String(THEMOVIEDB_API_VERSION), id));
-    u.addQueryItem(QLatin1String("api_key"), m_apiKey);
-    u.addQueryItem(QLatin1String("language"), m_locale);
-    u.addQueryItem(QLatin1String("append_to_response"),
+    QUrlQuery q;
+    q.addQueryItem(QLatin1String("api_key"), m_apiKey);
+    q.addQueryItem(QLatin1String("language"), m_locale);
+    q.addQueryItem(QLatin1String("append_to_response"),
                    QLatin1String("alternative_titles,credits"));
+    u.setQuery(q);
     QByteArray data = FileHandler::readDataFile(u, true);
 #if 0
     myWarning() << "Remove debug2 from themoviedbfetcher.cpp";
@@ -196,10 +195,20 @@ Tellico::Data::EntryPtr TheMovieDBFetcher::fetchEntryHook(uint uid_) {
     }
     f.close();
 #endif
-    QJson::Parser parser;
-    populateEntry(entry, parser.parse(data).toMap(), true);
+    QJsonDocument doc = QJsonDocument::fromJson(data);
+    populateEntry(entry, doc.object().toVariantMap(), true);
+  }
+
+  // image might still be a URL
+  const QString image_id = entry->field(QLatin1String("cover"));
+  if(image_id.contains(QLatin1Char('/'))) {
+    const QString id = ImageFactory::addImage(QUrl::fromUserInput(image_id), true /* quiet */);
+    if(id.isEmpty()) {
+      message(i18n("The cover image could not be loaded."), MessageHandler::Warning);
+    }
+    // empty image ID is ok
+    entry->setField(QLatin1String("cover"), id);
   }
-#endif
 
   // don't want to include TMDb ID field
   entry->setField(QLatin1String("tmdb-id"), QString());
@@ -217,8 +226,6 @@ Tellico::Fetch::FetchRequest TheMovieDBFetcher::updateRequest(Data::EntryPtr ent
 
 void TheMovieDBFetcher::slotComplete(KJob* job_) {
   KIO::StoredTransferJob* job = static_cast<KIO::StoredTransferJob*>(job_);
-#ifdef HAVE_QJSON
-//  myDebug();
 
   if(job->error()) {
     job->ui()->showErrorMessage();
@@ -274,8 +281,8 @@ void TheMovieDBFetcher::slotComplete(KJob* job_) {
     coll->addField(f);
   }
 
-  QJson::Parser parser;
-  QVariantMap result = parser.parse(data).toMap();
+  QJsonDocument doc = QJsonDocument::fromJson(data);
+  QVariantMap result = doc.object().toVariantMap();
 
   QVariantList resultList = result.value(QLatin1String("results")).toList();
   if(resultList.isEmpty()) {
@@ -285,7 +292,7 @@ void TheMovieDBFetcher::slotComplete(KJob* job_) {
   }
 
   foreach(const QVariant& result, resultList) {
-  //  myDebug() << "found result:" << result;
+//    myDebug() << "found result:" << result;
 
     Data::EntryPtr entry(new Data::Entry(coll));
     populateEntry(entry, result.toMap(), false);
@@ -295,7 +302,6 @@ void TheMovieDBFetcher::slotComplete(KJob* job_) {
     emit signalResultFound(r);
   }
 
-#endif
   stop();
 }
 
@@ -304,21 +310,26 @@ void TheMovieDBFetcher::populateEntry(Data::EntryPtr entry_, const QVariantMap&
   entry_->setField(QLatin1String("title"), value(resultMap_, "title"));
   entry_->setField(QLatin1String("year"),  value(resultMap_, "release_date").left(4));
 
+  QStringList directors, producers, writers, composers;
   QVariantList crewList = resultMap_.value(QLatin1String("credits")).toMap()
                                     .value(QLatin1String("crew")).toList();
   foreach(const QVariant& crew, crewList) {
-    QVariantMap crewMap = crew.toMap();
+    const QVariantMap crewMap = crew.toMap();
     const QString job = value(crewMap, "job");
     if(job == QLatin1String("Director")) {
-      entry_->setField(QLatin1String("director"), value(crewMap, "name"));
+      directors += value(crewMap, "name");
     } else if(job == QLatin1String("Producer")) {
-      entry_->setField(QLatin1String("producer"), value(crewMap, "name"));
+      producers += value(crewMap, "name");
     } else if(job == QLatin1String("Screenplay")) {
-      entry_->setField(QLatin1String("writer"), value(crewMap, "name"));
+      writers += value(crewMap, "name");
     } else if(job == QLatin1String("Original Music Composer")) {
-      entry_->setField(QLatin1String("composer"), value(crewMap, "name"));
+      composers += value(crewMap, "name");
     }
   }
+  entry_->setField(QLatin1String("director"), directors.join(FieldFormat::delimiterString()));
+  entry_->setField(QLatin1String("producer"), producers.join(FieldFormat::delimiterString()));
+  entry_->setField(QLatin1String("writer"),     writers.join(FieldFormat::delimiterString()));
+  entry_->setField(QLatin1String("composer"), composers.join(FieldFormat::delimiterString()));
 
   // if we only need cursory data, then we're done
   if(!fullData_) {
@@ -383,9 +394,11 @@ void TheMovieDBFetcher::populateEntry(Data::EntryPtr entry_, const QVariantMap&
 }
 
 void TheMovieDBFetcher::readConfiguration() {
-  KUrl u(THEMOVIEDB_API_URL);
-  u.setPath(QString::fromLatin1("%1/configuration").arg(QLatin1String(THEMOVIEDB_API_VERSION)));
-  u.addQueryItem(QLatin1String("api_key"), m_apiKey);
+  QUrl u(QString::fromLatin1(THEMOVIEDB_API_URL));
+  u.setPath(QString::fromLatin1("/%1/configuration").arg(QLatin1String(THEMOVIEDB_API_VERSION)));
+  QUrlQuery q;
+  q.addQueryItem(QLatin1String("api_key"), m_apiKey);
+  u.setQuery(q);
 
   QByteArray data = FileHandler::readDataFile(u, true);
 #if 0
@@ -399,8 +412,8 @@ void TheMovieDBFetcher::readConfiguration() {
   f.close();
 #endif
 
-  QJson::Parser parser;
-  QVariantMap resultMap = parser.parse(data).toMap();
+  QJsonDocument doc = QJsonDocument::fromJson(data);
+  QVariantMap resultMap = doc.object().toVariantMap();
 
   m_imageBase = value(resultMap.value(QLatin1String("images")).toMap(), "base_url");
   m_serverConfigDate = QDate::currentDate();
@@ -451,7 +464,7 @@ TheMovieDBFetcher::ConfigWidget::ConfigWidget(QWidget* parent_, const TheMovieDB
   QLabel* label = new QLabel(i18n("Access key: "), optionsWidget());
   l->addWidget(label, ++row, 0);
 
-  m_apiKeyEdit = new KLineEdit(optionsWidget());
+  m_apiKeyEdit = new QLineEdit(optionsWidget());
   connect(m_apiKeyEdit, SIGNAL(textChanged(const QString&)), SLOT(slotSetModified()));
   l->addWidget(m_apiKeyEdit, row, 1);
   QString w = i18n("The default Tellico key may be used, but searching may fail due to reaching access limits.");
@@ -516,5 +529,3 @@ QString TheMovieDBFetcher::value(const QVariantMap& map, const char* name) {
     return QString();
   }
 }
-
-#include "themoviedbfetcher.moc"
