@@ -24,7 +24,6 @@
 
 #include "fieldformat.h"
 #include "core/tellico_config.h"
-#include "tellico_debug.h"
 
 using Tellico::FieldFormat;
 
@@ -184,6 +183,10 @@ QString FieldFormat::name(const QString& name_, Options opt_) {
 
   // split the name by white space and commas
   QStringList words = name.split(spaceComma, QString::SkipEmptyParts);
+  // psycho case where name == ","
+  if(words.isEmpty()) {
+    return name;
+  }
 
   // if it contains a comma already and the last word is not a suffix, don't format it
   if(!opt_.testFlag(FormatAuto) ||
@@ -207,7 +210,10 @@ QString FieldFormat::name(const QString& name_, Options opt_) {
     words.removeLast();
 
     // this is probably just something for me, limited to english
-    while(Config::surnamePrefixList().contains(words.last(), Qt::CaseInsensitive)) {
+    // In a previous version of Tellico, using a prefix such as "van der" (with a space) would work
+    // because QStringList::contains did substring matching, but now need to add a function for tokenizing
+    // the list with whitespace as well as comma
+    while(Config::surnamePrefixTokens().contains(words.last(), Qt::CaseInsensitive)) {
       words.prepend(words.last());
       words.removeLast();
     }
@@ -247,8 +253,6 @@ QString FieldFormat::date(const QString& date_) {
   }
   // rather use ISO date formatting than locale formatting for now. Primarily, it makes sorting just work.
   return empty ? date_ : QDate(y, m, d).toString(Qt::ISODate);
-  // use short form
-//  return KGlobal::locale()->formatDate(date, true);
 }
 
 QString FieldFormat::capitalize(QString str_) {
@@ -299,7 +303,7 @@ QString FieldFormat::capitalize(QString str_) {
       // check against the noCapitalization list AND the surnamePrefix list
       // does this hold true everywhere other than english?
       if(!Config::noCapitalizationList().contains(word, Qt::CaseInsensitive) && 
-         !Config::surnamePrefixList().contains(word, Qt::CaseInsensitive) &&
+         !Config::surnamePrefixTokens().contains(word, Qt::CaseInsensitive) &&
          nextPos-pos > 1) {
         str_.replace(pos+1, 1, str_.at(pos+1).toUpper());
       }
