@@ -25,35 +25,37 @@
 #undef QT_NO_CAST_FROM_ASCII
 
 #include "amazonfetchertest.h"
-#include "amazonfetchertest.moc"
-#include "qtest_kde.h"
 
 #include "../fetch/amazonfetcher.h"
 #include "../collections/bookcollection.h"
 #include "../collections/musiccollection.h"
 #include "../collections/videocollection.h"
+#include "../collections/gamecollection.h"
 #include "../collectionfactory.h"
 #include "../entry.h"
-#include  "../images/imagefactory.h"
+#include "../images/imagefactory.h"
+#include "../utils/datafileregistry.h"
 
-#include <KStandardDirs>
 #include <KConfigGroup>
 
-QTEST_KDEMAIN( AmazonFetcherTest, GUI )
+#include <QTest>
+
+QTEST_GUILESS_MAIN( AmazonFetcherTest )
 
 AmazonFetcherTest::AmazonFetcherTest() : AbstractFetcherTest(), m_hasConfigFile(false)
-    , m_config(QString::fromLatin1(KDESRCDIR)  + "/amazonfetchertest.config", KConfig::SimpleConfig) {
+    , m_config(QFINDTESTDATA("amazonfetchertest.config"), KConfig::SimpleConfig) {
 }
 
 void AmazonFetcherTest::initTestCase() {
   Tellico::RegisterCollection<Tellico::Data::BookCollection> registerBook(Tellico::Data::Collection::Book, "book");
   Tellico::RegisterCollection<Tellico::Data::MusicCollection> registerMusic(Tellico::Data::Collection::Album, "music");
   Tellico::RegisterCollection<Tellico::Data::VideoCollection> registerVideo(Tellico::Data::Collection::Video, "mvideo");
+  Tellico::RegisterCollection<Tellico::Data::GameCollection> registerGame(Tellico::Data::Collection::Game, "game");
   // since we use an XSL file
-  KGlobal::dirs()->addResourceDir("appdata", QString::fromLatin1(KDESRCDIR) + "/../../xslt/");
+  Tellico::DataFileRegistry::self()->addDataLocation(QFINDTESTDATA("../../xslt/amazon2tellico.xsl"));
   Tellico::ImageFactory::init();
 
-  m_hasConfigFile = QFile::exists(QString::fromLatin1(KDESRCDIR)  + "/amazonfetchertest.config");
+  m_hasConfigFile = QFile::exists(QFINDTESTDATA("amazonfetchertest.config"));
 
   QHash<QString, QString> practicalRdf;
   practicalRdf.insert(QLatin1String("title"), QLatin1String("Practical RDF"));
@@ -137,7 +139,7 @@ void AmazonFetcherTest::testTitle() {
         locale == QLatin1String("CN") ||
         locale == QLatin1String("IT") ||
         locale == QLatin1String("DE"))) {
-      QVERIFY2(result.contains(i.value(), Qt::CaseInsensitive), i.key().toAscii());
+      QVERIFY2(result.contains(i.value(), Qt::CaseInsensitive), qPrintable(i.key()));
     } else if(collType == Tellico::Data::Collection::Video &&
        i.key() == QLatin1String("year") &&
        locale == QLatin1String("FR")) {
@@ -209,6 +211,30 @@ void AmazonFetcherTest::testTitle_data() {
 
 }
 
+void AmazonFetcherTest::testTitleVideoGame() {
+  QString groupName = QLatin1String("Amazon US");
+  if(!m_hasConfigFile || !m_config.hasGroup(groupName)) {
+    QSKIP("This test requires a config file with Amazon settings.", SkipAll);
+  }
+  KConfigGroup cg(&m_config, groupName);
+
+  Tellico::Fetch::FetchRequest request(Tellico::Data::Collection::Game, Tellico::Fetch::Title,
+                                       QLatin1String("Ghostbusters Story Pack - LEGO Dimensions"));
+  Tellico::Fetch::Fetcher::Ptr fetcher(new Tellico::Fetch::AmazonFetcher(this));
+  fetcher->readConfig(cg, cg.name());
+
+  Tellico::Data::EntryList results = DO_FETCH(fetcher, request);
+
+  QVERIFY(!results.isEmpty());
+
+  Tellico::Data::EntryPtr entry = results.at(0);
+  QVERIFY(entry);
+  QCOMPARE(entry->field("title"), QLatin1String("Ghostbusters Story Pack - LEGO Dimensions"));
+  QCOMPARE(entry->field("publisher"), QLatin1String("Warner Home Video - Games"));
+  // the E10+ ESRB rating was added to Tellico in 2017 in version 3.0.1
+  QCOMPARE(entry->field("certification"), QLatin1String("Everyone 10+"));
+}
+
 void AmazonFetcherTest::testIsbn() {
   QFETCH(QString, locale);
   QFETCH(QString, searchValue);
