@@ -25,57 +25,58 @@
 #undef QT_NO_CAST_FROM_ASCII
 
 #include "boardgamegeekfetchertest.h"
-#include "boardgamegeekfetchertest.moc"
-#include "qtest_kde.h"
 
 #include "../fetch/execexternalfetcher.h"
+#include "../fetch/boardgamegeekfetcher.h"
 #include "../collections/boardgamecollection.h"
 #include "../collectionfactory.h"
 #include "../entry.h"
 #include "../images/imagefactory.h"
+#include "../utils/datafileregistry.h"
 
-#include <KStandardDirs>
 #include <KConfigGroup>
 
-QTEST_KDEMAIN( BoardGameGeekFetcherTest, NoGUI )
+#include <QTest>
+
+QTEST_GUILESS_MAIN( BoardGameGeekFetcherTest )
 
 BoardGameGeekFetcherTest::BoardGameGeekFetcherTest() : AbstractFetcherTest() {
 }
 
 void BoardGameGeekFetcherTest::initTestCase() {
-  const QString ruby = KStandardDirs::findExe(QLatin1String("ruby"));
-  if(ruby.isEmpty()) {
-    QSKIP("This test requires ruby", SkipAll);
-  }
-
   Tellico::RegisterCollection<Tellico::Data::BoardGameCollection> registerBoard(Tellico::Data::Collection::BoardGame, "boardgame");
   Tellico::ImageFactory::init();
+  Tellico::DataFileRegistry::self()->addDataLocation(QFINDTESTDATA("../../xslt/boardgamegeek2tellico.xsl"));
 }
 
 void BoardGameGeekFetcherTest::testTitle() {
   Tellico::Fetch::FetchRequest request(Tellico::Data::Collection::BoardGame, Tellico::Fetch::Title,
-                                       QLatin1String("settlers of catan"));
-  Tellico::Fetch::Fetcher::Ptr fetcher(new Tellico::Fetch::ExecExternalFetcher(this));
-
-  KConfig config(QString::fromLatin1(KDESRCDIR) + "/../fetch/scripts/boardgamegeek.rb.spec", KConfig::SimpleConfig);
-  KConfigGroup cg = config.group(QLatin1String("<default>"));
-  cg.writeEntry("ExecPath", QString::fromLatin1(KDESRCDIR) + "/../fetch/scripts/boardgamegeek.rb");
-  // don't sync() and save the new path
-  cg.markAsClean();
-  fetcher->readConfig(cg, cg.name());
+                                       QLatin1String("Catan"));
+  Tellico::Fetch::Fetcher::Ptr fetcher(new Tellico::Fetch::BoardGameGeekFetcher(this));
 
   Tellico::Data::EntryList results = DO_FETCH1(fetcher, request, 1);
 
   QCOMPARE(results.size(), 1);
 
   Tellico::Data::EntryPtr entry = results.at(0);
-  QCOMPARE(entry->field(QLatin1String("title")), QLatin1String("The Settlers of Catan"));
+  QCOMPARE(entry->collection()->type(), Tellico::Data::Collection::BoardGame);
+  QCOMPARE(entry->field(QLatin1String("title")), QLatin1String("Catan"));
   QCOMPARE(entry->field(QLatin1String("designer")), QLatin1String("Klaus Teuber"));
-  QCOMPARE(Tellico::FieldFormat::splitValue(entry->field(QLatin1String("publisher"))).at(0), QLatin1String("999 Games"));
+  QCOMPARE(Tellico::FieldFormat::splitValue(entry->field(QLatin1String("publisher"))).at(0), QLatin1String("KOSMOS"));
   QCOMPARE(entry->field(QLatin1String("year")), QLatin1String("1995"));
-  QCOMPARE(Tellico::FieldFormat::splitValue(entry->field(QLatin1String("genre"))).at(0), QLatin1String("Civilization"));
+  QCOMPARE(Tellico::FieldFormat::splitValue(entry->field(QLatin1String("genre"))).at(0), QLatin1String("Negotiation"));
   QCOMPARE(Tellico::FieldFormat::splitValue(entry->field(QLatin1String("mechanism"))).at(0), QLatin1String("Dice Rolling"));
   QCOMPARE(entry->field(QLatin1String("num-player")), QLatin1String("3; 4"));
   QVERIFY(!entry->field(QLatin1String("cover")).isEmpty());
   QVERIFY(!entry->field(QLatin1String("description")).isEmpty());
 }
+
+void BoardGameGeekFetcherTest::testKeyword() {
+  Tellico::Fetch::FetchRequest request(Tellico::Data::Collection::BoardGame, Tellico::Fetch::Keyword,
+                                       QLatin1String("The Settlers of Catan"));
+  Tellico::Fetch::Fetcher::Ptr fetcher(new Tellico::Fetch::BoardGameGeekFetcher(this));
+
+  Tellico::Data::EntryList results = DO_FETCH(fetcher, request);
+
+  QCOMPARE(results.size(), 10);
+}
