@@ -25,43 +25,42 @@
 #undef QT_NO_CAST_FROM_ASCII
 
 #include "gcstartest.h"
-#include "gcstartest.moc"
-#include "qtest_kde.h"
 
 #include "../translators/gcstarimporter.h"
 #include "../translators/gcstarexporter.h"
 #include "../collections/collectioninitializer.h"
 #include "../collectionfactory.h"
 #include "../images/imagefactory.h"
+#include "../utils/datafileregistry.h"
 #include "../fieldformat.h"
 
-#include <kstandarddirs.h>
+#include <QTest>
 
 #define FIELDS(entry, fieldName) Tellico::FieldFormat::splitValue(entry->field(fieldName))
 #define TABLES(entry, fieldName) Tellico::FieldFormat::splitTable(entry->field(fieldName))
 
-QTEST_KDEMAIN_CORE( GCstarTest )
+QTEST_GUILESS_MAIN( GCstarTest )
 
 void GCstarTest::initTestCase() {
   Tellico::ImageFactory::init();
-  KGlobal::dirs()->addResourceDir("appdata", QString::fromLatin1(KDESRCDIR) + "/../../xslt/");
+  Tellico::DataFileRegistry::self()->addDataLocation(QFINDTESTDATA("../../xslt/gcstar2tellico.xsl"));
   // need to register the collection types
   Tellico::CollectionInitializer ci;
 }
 
 void GCstarTest::testBook() {
-  KUrl url(QString::fromLatin1(KDESRCDIR) + "/data/test-book.gcs");
+  QUrl url = QUrl::fromLocalFile(QFINDTESTDATA("data/test-book.gcs"));
   Tellico::Import::GCstarImporter importer(url);
   Tellico::Data::CollPtr coll = importer.collection();
 
-  QVERIFY(!coll.isNull());
+  QVERIFY(coll);
   QCOMPARE(coll->type(), Tellico::Data::Collection::Book);
   QCOMPARE(coll->entryCount(), 2);
   // should be translated somehow
   QCOMPARE(coll->title(), QLatin1String("GCstar Import"));
 
   Tellico::Data::EntryPtr entry = coll->entryById(1);
-  QVERIFY(!entry.isNull());
+  QVERIFY(entry);
   QCOMPARE(entry->field("title"), QLatin1String("The Reason for God"));
   QCOMPARE(entry->field("pub_year"), QLatin1String("2008"));
   QCOMPARE(FIELDS(entry, "author").count(), 2);
@@ -84,7 +83,7 @@ void GCstarTest::testBook() {
   Tellico::Import::GCstarImporter importer2(exporter.text());
   Tellico::Data::CollPtr coll2 = importer2.collection();
 
-  QVERIFY(!coll2.isNull());
+  QVERIFY(coll2);
   QCOMPARE(coll2->type(), coll->type());
   QCOMPARE(coll2->entryCount(), coll->entryCount());
   QCOMPARE(coll2->title(), coll->title());
@@ -102,18 +101,18 @@ void GCstarTest::testBook() {
 }
 
 void GCstarTest::testComicBook() {
-  KUrl url(QString::fromLatin1(KDESRCDIR) + "/data/test-comicbook.gcs");
+  QUrl url = QUrl::fromLocalFile(QFINDTESTDATA("data/test-comicbook.gcs"));
   Tellico::Import::GCstarImporter importer(url);
   Tellico::Data::CollPtr coll = importer.collection();
 
-  QVERIFY(!coll.isNull());
+  QVERIFY(coll);
   QCOMPARE(coll->type(), Tellico::Data::Collection::ComicBook);
   QCOMPARE(coll->entryCount(), 1);
   // should be translated somehow
   QCOMPARE(coll->title(), QLatin1String("GCstar Import"));
 
   Tellico::Data::EntryPtr entry = coll->entryById(1);
-  QVERIFY(!entry.isNull());
+  QVERIFY(entry);
   QCOMPARE(entry->field("title"), QLatin1String("title"));
   QCOMPARE(entry->field("pub_year"), QLatin1String("2010"));
   QCOMPARE(entry->field("series"), QLatin1String("series"));
@@ -142,7 +141,7 @@ void GCstarTest::testComicBook() {
   Tellico::Import::GCstarImporter importer2(exporter.text());
   Tellico::Data::CollPtr coll2 = importer2.collection();
 
-  QVERIFY(!coll2.isNull());
+  QVERIFY(coll2);
   QCOMPARE(coll2->type(), coll->type());
   QCOMPARE(coll2->entryCount(), coll->entryCount());
   QCOMPARE(coll2->title(), coll->title());
@@ -160,16 +159,16 @@ void GCstarTest::testComicBook() {
 }
 
 void GCstarTest::testVideo() {
-  KUrl url(QString::fromLatin1(KDESRCDIR) + "/data/test-video.gcs");
+  QUrl url = QUrl::fromLocalFile(QFINDTESTDATA("data/test-video.gcs"));
   Tellico::Import::GCstarImporter importer(url);
   Tellico::Data::CollPtr coll = importer.collection();
 
-  QVERIFY(!coll.isNull());
+  QVERIFY(coll);
   QCOMPARE(coll->type(), Tellico::Data::Collection::Video);
-  QCOMPARE(coll->entryCount(), 2);
+  QCOMPARE(coll->entryCount(), 3);
 
   Tellico::Data::EntryPtr entry = coll->entryById(2);
-  QVERIFY(!entry.isNull());
+  QVERIFY(entry);
   QCOMPARE(entry->field("title"), QLatin1String("The Man from Snowy River"));
   QCOMPARE(entry->field("year"), QLatin1String("1982"));
   QCOMPARE(FIELDS(entry, "director").count(), 1);
@@ -191,12 +190,19 @@ void GCstarTest::testVideo() {
   QVERIFY(!entry->field("plot").isEmpty());
   QVERIFY(!entry->field("comments").isEmpty());
 
+  entry = coll->entryById(4);
+  QVERIFY(entry);
+  castList = Tellico::FieldFormat::splitTable(entry->field("cast"));
+  QCOMPARE(castList.count(), 11);
+  QCOMPARE(castList.at(0), QLatin1String("Famke Janssen::Marnie Watson"));
+  QCOMPARE(entry->field("location"), QLatin1String("On Hard Drive"));
+
   Tellico::Export::GCstarExporter exporter(coll);
   exporter.setEntries(coll->entries());
   Tellico::Import::GCstarImporter importer2(exporter.text());
   Tellico::Data::CollPtr coll2 = importer2.collection();
 
-  QVERIFY(!coll2.isNull());
+  QVERIFY(coll2);
   QCOMPARE(coll2->type(), coll->type());
   QCOMPARE(coll2->entryCount(), coll->entryCount());
   QCOMPARE(coll2->title(), coll->title());
@@ -205,25 +211,33 @@ void GCstarTest::testVideo() {
     Tellico::Data::EntryPtr e2 = coll2->entryById(e1->id());
     QVERIFY(e2);
     foreach(Tellico::Data::FieldPtr f, coll->fields()) {
-      // skip images
-      if(f->type() != Tellico::Data::Field::Image) {
+      // skip images and tables
+      if(f->type() != Tellico::Data::Field::Image &&
+         f->type() != Tellico::Data::Field::Table) {
         QCOMPARE(f->name() + e2->field(f), f->name() + e1->field(f));
+      } else if(f->type() == Tellico::Data::Field::Table) {
+        QStringList rows1 = Tellico::FieldFormat::splitTable(e1->field(f));
+        QStringList rows2 = Tellico::FieldFormat::splitTable(e2->field(f));
+        QCOMPARE(rows1.count(), rows2.count());
+        for(int i = 0; i < rows1.count(); ++i) {
+          QCOMPARE(f->name() + rows2.at(i), f->name() + rows1.at(i));
+        }
       }
     }
   }
 }
 
 void GCstarTest::testMusic() {
-  KUrl url(QString::fromLatin1(KDESRCDIR) + "/data/test-music.gcs");
+  QUrl url = QUrl::fromLocalFile(QFINDTESTDATA("data/test-music.gcs"));
   Tellico::Import::GCstarImporter importer(url);
   Tellico::Data::CollPtr coll = importer.collection();
 
-  QVERIFY(!coll.isNull());
+  QVERIFY(coll);
   QCOMPARE(coll->type(), Tellico::Data::Collection::Album);
   QCOMPARE(coll->entryCount(), 1);
 
   Tellico::Data::EntryPtr entry = coll->entryById(1);
-  QVERIFY(!entry.isNull());
+  QVERIFY(entry);
   QCOMPARE(entry->field("title"), QLatin1String("Lifesong"));
   QCOMPARE(entry->field("year"), QLatin1String("2005"));
   QCOMPARE(FIELDS(entry, "artist").count(), 1);
@@ -247,7 +261,7 @@ void GCstarTest::testMusic() {
   Tellico::Import::GCstarImporter importer2(exporter.text());
   Tellico::Data::CollPtr coll2 = importer2.collection();
 
-  QVERIFY(!coll2.isNull());
+  QVERIFY(coll2);
   QCOMPARE(coll2->type(), coll->type());
   QCOMPARE(coll2->entryCount(), coll->entryCount());
   QCOMPARE(coll2->title(), coll->title());
@@ -265,16 +279,16 @@ void GCstarTest::testMusic() {
 }
 
 void GCstarTest::testVideoGame() {
-  KUrl url(QString::fromLatin1(KDESRCDIR) + "/data/test-videogame.gcs");
+  QUrl url = QUrl::fromLocalFile(QFINDTESTDATA("data/test-videogame.gcs"));
   Tellico::Import::GCstarImporter importer(url);
   Tellico::Data::CollPtr coll = importer.collection();
 
-  QVERIFY(!coll.isNull());
+  QVERIFY(coll);
   QCOMPARE(coll->type(), Tellico::Data::Collection::Game);
   QCOMPARE(coll->entryCount(), 2);
 
   Tellico::Data::EntryPtr entry = coll->entryById(2);
-  QVERIFY(!entry.isNull());
+  QVERIFY(entry);
   QCOMPARE(entry->field("title"), QLatin1String("Halo 3"));
   QCOMPARE(entry->field("year"), QLatin1String("2007"));
   QCOMPARE(entry->field("platform"), QLatin1String("Xbox 360"));
@@ -292,7 +306,7 @@ void GCstarTest::testVideoGame() {
   Tellico::Import::GCstarImporter importer2(exporter.text());
   Tellico::Data::CollPtr coll2 = importer2.collection();
 
-  QVERIFY(!coll2.isNull());
+  QVERIFY(coll2);
   QCOMPARE(coll2->type(), coll->type());
   QCOMPARE(coll2->entryCount(), coll->entryCount());
   QCOMPARE(coll2->title(), coll->title());
@@ -310,16 +324,16 @@ void GCstarTest::testVideoGame() {
 }
 
 void GCstarTest::testBoardGame() {
-  KUrl url(QString::fromLatin1(KDESRCDIR) + "/data/test-boardgame.gcs");
+  QUrl url = QUrl::fromLocalFile(QFINDTESTDATA("data/test-boardgame.gcs"));
   Tellico::Import::GCstarImporter importer(url);
   Tellico::Data::CollPtr coll = importer.collection();
 
-  QVERIFY(!coll.isNull());
+  QVERIFY(coll);
   QCOMPARE(coll->type(), Tellico::Data::Collection::BoardGame);
   QCOMPARE(coll->entryCount(), 2);
 
   Tellico::Data::EntryPtr entry = coll->entryById(1);
-  QVERIFY(!entry.isNull());
+  QVERIFY(entry);
   QCOMPARE(entry->field("title"), QLatin1String("Risk"));
   QCOMPARE(entry->field("year"), QLatin1String("1959"));
   QCOMPARE(FIELDS(entry, "designer").count(), 2);
@@ -338,7 +352,7 @@ void GCstarTest::testBoardGame() {
   Tellico::Import::GCstarImporter importer2(exporter.text());
   Tellico::Data::CollPtr coll2 = importer2.collection();
 
-  QVERIFY(!coll2.isNull());
+  QVERIFY(coll2);
   QCOMPARE(coll2->type(), coll->type());
   QCOMPARE(coll2->entryCount(), coll->entryCount());
   QCOMPARE(coll2->title(), coll->title());
@@ -356,16 +370,16 @@ void GCstarTest::testBoardGame() {
 }
 
 void GCstarTest::testWine() {
-  KUrl url(QString::fromLatin1(KDESRCDIR) + "/data/test-wine.gcs");
+  QUrl url = QUrl::fromLocalFile(QFINDTESTDATA("data/test-wine.gcs"));
   Tellico::Import::GCstarImporter importer(url);
   Tellico::Data::CollPtr coll = importer.collection();
 
-  QVERIFY(!coll.isNull());
+  QVERIFY(coll);
   QCOMPARE(coll->type(), Tellico::Data::Collection::Wine);
   QCOMPARE(coll->entryCount(), 1);
 
   Tellico::Data::EntryPtr entry = coll->entryById(1);
-  QVERIFY(!entry.isNull());
+  QVERIFY(entry);
   QCOMPARE(entry->field("vintage"), QLatin1String("1990"));
   QCOMPARE(entry->field("producer"), QLatin1String("producer"));
   QCOMPARE(entry->field("type"), QLatin1String("Red Wine"));
@@ -391,7 +405,7 @@ void GCstarTest::testWine() {
   Tellico::Import::GCstarImporter importer2(exporter.text());
   Tellico::Data::CollPtr coll2 = importer2.collection();
 
-  QVERIFY(!coll2.isNull());
+  QVERIFY(coll2);
   QCOMPARE(coll2->type(), coll->type());
   QCOMPARE(coll2->entryCount(), coll->entryCount());
   QCOMPARE(coll2->title(), coll->title());
@@ -409,16 +423,16 @@ void GCstarTest::testWine() {
 }
 
 void GCstarTest::testCoin() {
-  KUrl url(QString::fromLatin1(KDESRCDIR) + "/data/test-coin.gcs");
+  QUrl url = QUrl::fromLocalFile(QFINDTESTDATA("data/test-coin.gcs"));
   Tellico::Import::GCstarImporter importer(url);
   Tellico::Data::CollPtr coll = importer.collection();
 
-  QVERIFY(!coll.isNull());
+  QVERIFY(coll);
   QCOMPARE(coll->type(), Tellico::Data::Collection::Coin);
   QCOMPARE(coll->entryCount(), 1);
 
   Tellico::Data::EntryPtr entry = coll->entryById(1);
-  QVERIFY(!entry.isNull());
+  QVERIFY(entry);
   QCOMPARE(entry->field("denomination"), QLatin1String("0.05"));
   QCOMPARE(entry->field("year"), QLatin1String("1974"));
   QCOMPARE(entry->field("currency"), QLatin1String("USD"));
@@ -437,7 +451,7 @@ void GCstarTest::testCoin() {
   Tellico::Import::GCstarImporter importer2(exporter.text());
   Tellico::Data::CollPtr coll2 = importer2.collection();
 
-  QVERIFY(!coll2.isNull());
+  QVERIFY(coll2);
   QCOMPARE(coll2->type(), coll->type());
   QCOMPARE(coll2->entryCount(), coll->entryCount());
   QCOMPARE(coll2->title(), coll->title());
@@ -455,11 +469,11 @@ void GCstarTest::testCoin() {
 }
 
 void GCstarTest::testCustomFields() {
-  KUrl url(QString::fromLatin1(KDESRCDIR) + "/data/test-book.gcs");
+  QUrl url = QUrl::fromLocalFile(QFINDTESTDATA("data/test-book.gcs"));
   Tellico::Import::GCstarImporter importer(url);
   Tellico::Data::CollPtr coll = importer.collection();
 
-  QVERIFY(!coll.isNull());
+  QVERIFY(coll);
   QCOMPARE(coll->type(), Tellico::Data::Collection::Book);
   QCOMPARE(coll->entryCount(), 2);
   // should be translated somehow
@@ -467,14 +481,14 @@ void GCstarTest::testCustomFields() {
 
   // test custom fields
   Tellico::Data::FieldPtr field = coll->fieldByName(QLatin1String("gcsfield1"));
-  QVERIFY(!field.isNull());
+  QVERIFY(field);
   QCOMPARE(field->name(), QLatin1String("gcsfield1"));
   QCOMPARE(field->title(), QLatin1String("New boolean"));
   QCOMPARE(field->category(), QLatin1String("User fields"));
   QCOMPARE(field->type(), Tellico::Data::Field::Bool);
 
   field = coll->fieldByName(QLatin1String("gcsfield2"));
-  QVERIFY(!field.isNull());
+  QVERIFY(field);
   QCOMPARE(field->title(), QLatin1String("New choice"));
   QCOMPARE(field->type(), Tellico::Data::Field::Choice);
   QCOMPARE(field->allowed(), QStringList() << QLatin1String("yes")
@@ -482,52 +496,52 @@ void GCstarTest::testCustomFields() {
                                            << QLatin1String("maybe"));
 
   field = coll->fieldByName(QLatin1String("gcsfield3"));
-  QVERIFY(!field.isNull());
+  QVERIFY(field);
   QCOMPARE(field->title(), QLatin1String("New rating"));
   QCOMPARE(field->type(), Tellico::Data::Field::Rating);
   QCOMPARE(field->property(QLatin1String("minimum")), QLatin1String("1"));
   QCOMPARE(field->property(QLatin1String("maximum")), QLatin1String("5"));
 
   field = coll->fieldByName(QLatin1String("gcsfield4"));
-  QVERIFY(!field.isNull());
+  QVERIFY(field);
   QCOMPARE(field->title(), QLatin1String("New field"));
   QCOMPARE(field->type(), Tellico::Data::Field::Line);
 
   field = coll->fieldByName(QLatin1String("gcsfield5"));
-  QVERIFY(!field.isNull());
+  QVERIFY(field);
   QCOMPARE(field->title(), QLatin1String("New image"));
   QCOMPARE(field->type(), Tellico::Data::Field::Image);
 
   field = coll->fieldByName(QLatin1String("gcsfield6"));
-  QVERIFY(!field.isNull());
+  QVERIFY(field);
   QCOMPARE(field->title(), QLatin1String("New long field"));
   QCOMPARE(field->type(), Tellico::Data::Field::Para);
 
   field = coll->fieldByName(QLatin1String("gcsfield7"));
-  QVERIFY(!field.isNull());
+  QVERIFY(field);
   QCOMPARE(field->title(), QLatin1String("New date"));
   QCOMPARE(field->type(), Tellico::Data::Field::Date);
 
   field = coll->fieldByName(QLatin1String("gcsfield8"));
-  QVERIFY(!field.isNull());
+  QVERIFY(field);
   QCOMPARE(field->title(), QLatin1String("New number"));
   QCOMPARE(field->type(), Tellico::Data::Field::Number);
   QCOMPARE(field->defaultValue(), QLatin1String("2"));
 
   field = coll->fieldByName(QLatin1String("gcsfield9"));
-  QVERIFY(!field.isNull());
+  QVERIFY(field);
   QCOMPARE(field->title(), QLatin1String("dependency"));
   QCOMPARE(field->type(), Tellico::Data::Field::Line);
   QCOMPARE(field->property(QLatin1String("template")), QLatin1String("%{gcsfield1},%{gcsfield2}"));
 
   field = coll->fieldByName(QLatin1String("gcsfield10"));
-  QVERIFY(!field.isNull());
+  QVERIFY(field);
   QCOMPARE(field->title(), QLatin1String("list"));
   QCOMPARE(field->type(), Tellico::Data::Field::Table);
   QCOMPARE(field->property(QLatin1String("columns")), QLatin1String("1"));
 
   Tellico::Data::EntryPtr entry = coll->entryById(2);
-  QVERIFY(!entry.isNull());
+  QVERIFY(entry);
   QCOMPARE(entry->field("gcsfield1"), QLatin1String("true"));
   QCOMPARE(entry->field("gcsfield2"), QLatin1String("maybe"));
   QCOMPARE(entry->field("gcsfield3"), QLatin1String("3"));
@@ -543,11 +557,11 @@ void GCstarTest::testCustomFields() {
 
   Tellico::Import::GCstarImporter importer2(exporter.text());
   Tellico::Data::CollPtr coll2 = importer2.collection();
-  QVERIFY(!coll2.isNull());
+  QVERIFY(coll2);
 
   foreach(Tellico::Data::FieldPtr f1, coll->fields()) {
     Tellico::Data::FieldPtr f2 = coll2->fieldByName(f1->name());
-    QVERIFY2(f2, f1->name().toLatin1());
+    QVERIFY2(f2, qPrintable(f1->name()));
     QCOMPARE(f1->name(), f2->name());
     QCOMPARE(f1->title(), f2->title());
     QCOMPARE(f1->category(), f2->category());
