@@ -25,18 +25,17 @@
 #undef QT_NO_CAST_FROM_ASCII
 
 #include "isbndbfetchertest.h"
-#include "isbndbfetchertest.moc"
-#include "qtest_kde.h"
 
 #include "../fetch/isbndbfetcher.h"
 #include "../entry.h"
 #include "../collections/bookcollection.h"
 #include "../collectionfactory.h"
 #include "../images/imagefactory.h"
+#include "../utils/datafileregistry.h"
 
-#include <KStandardDirs>
+#include <QTest>
 
-QTEST_KDEMAIN( ISBNdbFetcherTest, GUI )
+QTEST_GUILESS_MAIN( ISBNdbFetcherTest )
 
 ISBNdbFetcherTest::ISBNdbFetcherTest() : AbstractFetcherTest() {
 }
@@ -44,7 +43,7 @@ ISBNdbFetcherTest::ISBNdbFetcherTest() : AbstractFetcherTest() {
 void ISBNdbFetcherTest::initTestCase() {
   Tellico::ImageFactory::init();
   Tellico::RegisterCollection<Tellico::Data::BookCollection> registerBook(Tellico::Data::Collection::Book, "book");
-  KGlobal::dirs()->addResourceDir("appdata", QString::fromLatin1(KDESRCDIR) + "/../../xslt/");
+  Tellico::DataFileRegistry::self()->addDataLocation(QFINDTESTDATA("../../xslt/isbndb2tellico.xsl"));
 }
 
 void ISBNdbFetcherTest::testIsbn() {
@@ -123,9 +122,9 @@ void ISBNdbFetcherTest::testAuthor() {
   Tellico::Data::EntryPtr entry= results.at(0);
   QCOMPARE(entry->field(QLatin1String("title")), QLatin1String("Moonwalking with Einstein"));
   QCOMPARE(entry->field(QLatin1String("author")), QLatin1String("Joshua Foer"));
-  QCOMPARE(entry->field(QLatin1String("isbn")).remove('-'), QLatin1String("159420229X"));
-  QCOMPARE(entry->field(QLatin1String("pub_year")), QLatin1String("2011"));
-  QCOMPARE(entry->field(QLatin1String("publisher")), QLatin1String("Penguin Press HC, The"));
-  QCOMPARE(entry->field(QLatin1String("binding")), QLatin1String("Hardback"));
+  QCOMPARE(entry->field(QLatin1String("isbn")).remove('-'), QLatin1String("0143120530"));
+  QCOMPARE(entry->field(QLatin1String("pub_year")), QLatin1String("2012"));
+  QCOMPARE(entry->field(QLatin1String("publisher")), QLatin1String("Penguin (Non-Classics)"));
+  QCOMPARE(entry->field(QLatin1String("binding")), QLatin1String("Paperback"));
   QVERIFY(!entry->field(QLatin1String("comments")).isEmpty());
 }
