@@ -25,21 +25,19 @@
 #include "deliciousimporter.h"
 #include "../collection.h"
 #include "../images/imagefactory.h"
+#include "../utils/datafileregistry.h"
 #include "../tellico_debug.h"
 
 #include "rtf2html/rtf2html.h"
 
-#include <kstandarddirs.h>
-
 #include <QFile>
 
 using Tellico::Import::DeliciousImporter;
 
-DeliciousImporter::DeliciousImporter(const KUrl& url_) : XSLTImporter(url_) {
-  QString xsltFile = KStandardDirs::locate("appdata", QLatin1String("delicious2tellico.xsl"));
+DeliciousImporter::DeliciousImporter(const QUrl& url_) : XSLTImporter(url_) {
+  QString xsltFile = DataFileRegistry::self()->locate(QLatin1String("delicious2tellico.xsl"));
   if(!xsltFile.isEmpty()) {
-    KUrl u;
-    u.setPath(xsltFile);
+    QUrl u = QUrl::fromLocalFile(xsltFile);
     XSLTImporter::setXSLTURL(u);
   } else {
     myWarning() << "unable to find delicious2tellico.xml!";
@@ -59,8 +57,8 @@ Tellico::Data::CollPtr DeliciousImporter::collection() {
     return Data::CollPtr();
   }
 
-  KUrl libraryDir = url();
-  libraryDir.setPath(url().directory() + QLatin1String("Images/"));
+  QUrl libraryDir = url();
+  libraryDir.setPath(url().adjusted(QUrl::StripTrailingSlash|QUrl::RemoveFilename).path() + QLatin1String("Images/"));
   const QStringList imageDirs = QStringList()
                              << QLatin1String("Large Covers/")
                              << QLatin1String("Medium Covers/")
@@ -100,7 +98,7 @@ Tellico::Data::CollPtr DeliciousImporter::collection() {
         if(!QFile::exists(imgPath)) {
           continue;
         }
-        QString imgID = ImageFactory::addImage(imgPath, true);
+        QString imgID = ImageFactory::addImage(QUrl::fromLocalFile(imgPath), true);
         if(!imgID.isEmpty()) {
           entry->setField(coverField, imgID);
         }
@@ -117,5 +115,3 @@ Tellico::Data::CollPtr DeliciousImporter::collection() {
 
   return coll;
 }
-
-#include "deliciousimporter.moc"
