@@ -24,28 +24,26 @@
 
 #include "tellicoxmlexporter.h"
 #include "tellico_xml.h"
+#include "../utils/bibtexhandler.h" // needed for cleaning text
 #include "../entrygroup.h"
 #include "../collections/bibtexcollection.h"
 #include "../images/imagefactory.h"
 #include "../images/image.h"
 #include "../images/imageinfo.h"
 #include "../core/filehandler.h"
-#include "../tellico_utils.h"
+#include "../utils/string_utils.h"
 #include "../document.h"
 #include "../fieldformat.h"
-#include "../translators/bibtexhandler.h" // needed for cleaning text
 #include "../models/entrysortmodel.h"
 #include "../models/modelmanager.h"
 #include "../models/modeliterator.h"
 #include "../models/models.h"
 #include "../tellico_debug.h"
 
-#include <klocale.h>
+#include <KLocalizedString>
 #include <KConfigGroup>
-#include <kcodecs.h>
-#include <kglobal.h>
-#include <kcalendarsystem.h>
 
+#include <QDir>
 #include <QGroupBox>
 #include <QCheckBox>
 #include <QDomDocument>
@@ -58,7 +56,7 @@ using namespace Tellico;
 using Tellico::Export::TellicoXMLExporter;
 
 TellicoXMLExporter::TellicoXMLExporter(Tellico::Data::CollPtr coll) : Exporter(coll),
-      m_includeImages(false), m_includeGroups(false), m_widget(0) {
+      m_includeImages(false), m_includeGroups(false), m_widget(0), m_checkIncludeImages(0) {
   setOptions(options() | Export::ExportImages | Export::ExportImageSize); // not included by default
 }
 
@@ -67,7 +65,7 @@ QString TellicoXMLExporter::formatString() const {
 }
 
 QString TellicoXMLExporter::fileFilter() const {
-  return i18n("*.xml|XML Files (*.xml)") + QLatin1Char('\n') + i18n("*|All Files");
+  return i18n("XML Files") + QLatin1String(" (*.xml)") + QLatin1String(";;") + i18n("All Files") + QLatin1String(" (*)");
 }
 
 bool TellicoXMLExporter::exec() {
@@ -322,7 +320,8 @@ void TellicoXMLExporter::exportEntryXML(QDomDocument& dom_, QDomElement& parent_
       entryElem.appendChild(fieldElem);
       // Date fields get special treatment
       if(fIt->type() == Data::Field::Date) {
-        fieldElem.setAttribute(QLatin1String("calendar"), KGlobal::locale()->calendar()->calendarType());
+        // as of Tellico in KF5 (3.0), just forget about the calendar attribute for the moment, always use gregorian
+        fieldElem.setAttribute(QLatin1String("calendar"), QLatin1String("gregorian"));
         QStringList s = fieldValue.split(QLatin1Char('-'), QString::KeepEmptyParts);
         if(s.count() > 0 && !s[0].isEmpty()) {
           QDomElement e = dom_.createElement(QLatin1String("year"));
@@ -343,8 +342,9 @@ void TellicoXMLExporter::exportEntryXML(QDomDocument& dom_, QDomElement& parent_
                 fIt->property(QLatin1String("relative")) == QLatin1String("true") &&
                 !url().isEmpty()) {
         // if a relative URL and url() is not empty, change the value!
-        KUrl old_url(Data::Document::self()->URL(), fieldValue);
-        fieldElem.appendChild(dom_.createTextNode(KUrl::relativeUrl(url(), old_url)));
+        QUrl old_url = Data::Document::self()->URL().resolved(QUrl(fieldValue));
+        QString relPath = QDir(url().toLocalFile()).relativeFilePath(old_url.path());
+        fieldElem.appendChild(dom_.createTextNode(relPath));
       } else {
         fieldElem.appendChild(dom_.createTextNode(fieldValue));
       }
@@ -381,7 +381,7 @@ void TellicoXMLExporter::exportImageXML(QDomDocument& dom_, QDomElement& parent_
     if(img.linkOnly()) {
       imgElem.setAttribute(QLatin1String("link"), QLatin1String("true"));
     }
-    QByteArray imgText = KCodecs::base64Encode(img.byteArray());
+    QByteArray imgText = img.byteArray().toBase64();
     imgElem.appendChild(dom_.createTextNode(QLatin1String(imgText)));
   } else {
     const Data::ImageInfo& info = ImageFactory::imageInfo(id_);
@@ -463,6 +463,13 @@ void TellicoXMLExporter::exportFilterXML(QDomDocument& dom_, QDomElement& parent
       case FilterRule::FuncAfter:
         ruleElem.setAttribute(QLatin1String("function"), QLatin1String("after"));
         break;
+      case FilterRule::FuncGreater:
+        ruleElem.setAttribute(QLatin1String("function"), QLatin1String("greaterthan"));
+        break;
+      case FilterRule::FuncLess:
+        ruleElem.setAttribute(QLatin1String("function"), QLatin1String("lessthan"));
+        break;
+      /* If anything is updated here, be sure to update xmlstatehandler */
     }
     filterElem.appendChild(ruleElem);
   }
@@ -578,7 +585,9 @@ bool TellicoXMLExporter::version12Needed() const {
   foreach(FilterPtr filter, collection()->filters()) {
     foreach(FilterRule* rule, *filter) {
       if(rule->function() == FilterRule::FuncBefore ||
-         rule->function() == FilterRule::FuncAfter) {
+         rule->function() == FilterRule::FuncAfter ||
+         rule->function() == FilterRule::FuncGreater ||
+         rule->function() == FilterRule::FuncLess) {
         return true;
       }
     }
@@ -586,4 +595,3 @@ bool TellicoXMLExporter::version12Needed() const {
   return false;
 }
 
-#include "tellicoxmlexporter.moc"
